Index: lib/mpl_toolkits/mplot3d/axis3d.py
===================================================================
--- lib/mpl_toolkits/mplot3d/axis3d.py	(revision 8565)
+++ lib/mpl_toolkits/mplot3d/axis3d.py	(working copy)
@@ -284,8 +284,16 @@
         renderer.close_group('axis3d')
 
     def get_view_interval(self):
-        """return the Interval instance for this axis view limits"""
+        """return the Interval instance for this 3d axis view limits"""
         return self.v_interval
+        
+    def set_view_interval(self, vmin, vmax, ignore=False):
+        if ignore:
+            self.v_interval = vmin, vmax
+        else:
+            Vmin, Vmax = self.get_view_interval()
+            self.v_interval = min(vmin, Vmin), max(vmax, Vmax)
+        
 
 # Each type of axis should be looking in a different place for its
 # current data limits so we do this with classes.  I think there is
Index: lib/mpl_toolkits/mplot3d/axes3d.py
===================================================================
--- lib/mpl_toolkits/mplot3d/axes3d.py	(revision 8565)
+++ lib/mpl_toolkits/mplot3d/axes3d.py	(working copy)
@@ -264,6 +264,109 @@
     def get_zlim3d(self):
         '''Get 3D z limits.'''
         return self.zz_viewLim.intervalx
+        
+    def set_xticks3d(self,*args,**kw):
+        """
+        Set x tick locations and (optionally labels):
+        
+        #set locations of ticks
+        set_xticks3d( arange(5) )
+        
+        #set locations and labels of ticks
+        set_xticks3d([1,2,3],['1.0',2','3.000'])
+        
+        The keyword args, if any, are :class:`~matplotlib.text.Text`
+        properties.
+        """
+        if len(args) == 1:
+            self.w_xaxis.set_ticks(args[0])
+        elif len(args) == 2:
+            self.w_xaxis.set_ticks(args[0])
+            self.w_xaxis.set_ticklabels(args[1],**kw)
+        else:
+            raise TypeError('Illegal number of arguments to set_xticks3d')
+            
+        return self.get_xticks3d()
+            
+    def set_yticks3d(self,*args,**kw):
+        """
+        Set y tick locations and (optionally labels):
+        
+        #set locations of ticks
+        set_yticks3d( arange(5) )
+        
+        #set locations and labels of ticks
+        set_yticks3d([1,2,3],['1.0',2','3.000'])
+        
+        The keyword args, if any, are :class:`~matplotlib.text.Text`
+        properties.
+        """
+        if len(args) == 1:
+            self.w_yaxis.set_ticks(args[0])
+        elif len(args) == 2:
+            self.w_yaxis.set_ticks(args[0])
+            self.w_yaxis.set_ticklabels(args[1],**kw)
+        else:
+            raise TypeError('Illegal number of arguments to set_yticks3d')
+            
+        return self.get_yticks3d()
+            
+    def set_zticks3d(self,*args,**kw):
+        """
+        Set z tick locations and (optionally labels):
+        
+        #set locations of ticks
+        set_zticks3d( arange(5) )
+        
+        #set locations and labels of ticks
+        set_zticks3d([1,2,3],['1.0',2','3.000'])
+        
+        The keyword args, if any, are :class:`~matplotlib.text.Text`
+        properties.
+        """
+        if len(args) == 1:
+            self.w_zaxis.set_ticks(args[0])
+        elif len(args) == 2:
+            self.w_zaxis.set_ticks(args[0])
+            self.w_zaxis.set_ticklabels(args[1],**kw)
+        else:
+            raise TypeError('Illegal number of arguments to set_xticks3d')
+            
+        return self.get_xticks3d()
+        
+    def get_xticks3d(self):
+        """
+        # return locs, labels where locs is an array of tick locations and
+        # labels is an array of tick labels.
+        locs, labels = get_xticks3d()
+        """
+        locs = self.w_xaxis.get_ticklocs()
+        labels = self.w_xaxis.get_ticklabels()
+        
+        return locs,labels
+        
+    def get_yticks3d(self):
+        """
+        # return locs, labels where locs is an array of tick locations and
+        # labels is an array of tick labels.
+        locs, labels = get_yticks3d()
+        """
+        locs = self.w_yaxis.get_ticklocs()
+        labels = self.w_yaxis.get_ticklabels()
+        
+        return locs,labels
+        
+    def get_zticks3d(self):
+        """
+        # return locs, labels where locs is an array of tick locations and
+        # labels is an array of tick labels.
+        locs, labels = get_zticks3d()
+        """
+        locs = self.w_zaxis.get_ticklocs()
+        labels = self.w_zaxis.get_ticklabels()
+        
+        return locs,labels
+        
 
     def clabel(self, *args, **kwargs):
         return None
